Use the term `invalid' instead of `illegal'.
authorGerd Moellmann <gerd@gnu.org>
Tue, 16 May 2000 14:29:08 +0000 (14:29 +0000)
committerGerd Moellmann <gerd@gnu.org>
Tue, 16 May 2000 14:29:08 +0000 (14:29 +0000)
src/emacs.c
src/msdos.c
src/print.c
src/w32.c
src/xdisp.c

index ddb540e..ab3c7bc 100644 (file)
@@ -314,7 +314,7 @@ handle_USR2_signal (sig)
 }
 #endif /* SIGUSR2 */
 
-/* Handle bus errors, illegal instruction, etc. */
+/* Handle bus errors, invalid instruction, etc. */
 SIGTYPE
 fatal_error_signal (sig)
      int sig;
index d56ee7c..cfb19c6 100644 (file)
@@ -372,7 +372,7 @@ dosv_refresh_virtual_screen (int offset, int count)
 {
   __dpmi_regs regs;
 
-  if (offset < 0 || count < 0) /* paranoia; illegal values crash DOS/V */
+  if (offset < 0 || count < 0) /* paranoia; invalid values crash DOS/V */
     return;
 
   regs.h.ah = 0xff;    /* update relocated screen */
index 80a897f..2379e9d 100644 (file)
@@ -1490,7 +1490,7 @@ print_object (obj, printcharfun, escapeflag)
            int print_length, i;
            Lisp_Object halftail = obj;
 
-           /* Negative values of print-length are illegal in CL.
+           /* Negative values of print-length are invalid in CL.
               Treat them like nil, as CMUCL does.  */
            if (NATNUMP (Vprint_length))
              print_length = XFASTINT (Vprint_length);
@@ -1594,7 +1594,7 @@ print_object (obj, printcharfun, escapeflag)
          PRINTCHAR ('\"');
 
          /* Don't print more characters than the specified maximum.
-            Negative values of print-length are illegal.  Treat them
+            Negative values of print-length are invalid.  Treat them
             like a print-length of nil.  */
          if (NATNUMP (Vprint_length)
              && XFASTINT (Vprint_length) < size_in_chars)
index 67cf950..a7fd593 100644 (file)
--- a/src/w32.c
+++ b/src/w32.c
@@ -468,7 +468,7 @@ get_long_basename (char * name, char * buf, int size)
   HANDLE dir_handle;
   int len = 0;
 
/* must be valid filename, no wild cards or other illegal characters */
   if (strpbrk (name, "*?|<>\""))
     return 0;
 
@@ -1913,7 +1913,7 @@ stat (const char * path, struct stat * buf)
     }
 
   name = (char *) map_w32_filename (path, &path);
/* must be valid filename, no wild cards or other illegal characters */
   if (strpbrk (name, "*?|<>\""))
     {
       errno = ENOENT;
index b632312..411f621 100644 (file)
@@ -878,7 +878,7 @@ window_box_edges (w, area, top_left_x, top_left_y,
 /* Return the next character from STR which is MAXLEN bytes long.
    Return in *LEN the length of the character.  This is like
    STRING_CHAR_AND_LENGTH but never returns an invalid character.  If
-   we find one, we return a `?', but with the length of the illegal
+   we find one, we return a `?', but with the length of the invalid
    character.  */
 
 static INLINE int
@@ -891,7 +891,7 @@ string_char_and_length (str, maxlen, len)
   c = STRING_CHAR_AND_LENGTH (str, maxlen, *len);
   if (!CHAR_VALID_P (c, 1))
     /* We may not change the length here because other places in Emacs
-       don't use this function, i.e. they silently accept illegal
+       don't use this function, i.e. they silently accept invalid
        characters.  */
     c = '?';
@@ -468,7 +468,7 @@ get_long_basename (char * name, char * buf, int size)
   int len = 0;
 
-  /* must be valid filename, no wild cards or other illegal characters */
+  /* must be valid filename, no wild cards or other invalid characters */
   if (strpbrk (name, "*?|<>\""))
     return 0;
@@ -1913,7 +1913,7 @@ stat (const char * path, struct stat * buf)
 
   name = (char *) map_w32_filename (path, &path);
-  /* must be valid filename, no wild cards or other illegal characters */
+  /* must be valid filename, no wild cards or other invalid characters */
   if (strpbrk (name, "*?|<>\""))
     {